@@ -18,13 +18,13 @@ dofile(enigma.FindDataFile("levels/ralf_sokoban.lua"))
 level={
   "!####!####!",
   "##  ###  ##",
-  "#   #_#   #",
-  "#  *._.*  #",
-  "###o___o###",
-  "!#___@___#!",
-  "###o___o###",
-  "#  *._.*  #",
-  "#   #_#   #",
+  "#   # #   #",
+  "#  *. .*  #",
+  "###o   o###",
+  "!#   @   #!",
+  "###o   o###",
+  "#  *. .*  #",
+  "#   # #   #",
   "##  ###  ##",
   "!####!####!",
 }
