@@ -20,14 +20,14 @@ level={
   "!!##   #!!!!!!",
   "###  # #!!!!!!",
   "#    . #!!!!!!",
-  "#  ## #####!!!",
-  "#  . . #  ##!!",
-  "#  # @ o   ###",
-  "#####. #  o  #",
-  "!!!!####  o  #",
-  "!!!!!!!## o ##",
-  "!!!!!!!!#  ##!",
-  "!!!!!!!!#  #!!",
+  "#  ##_#####!!!",
+  "#  ._._#__##!!",
+  "#  #_a_O___###",
+  "#####._#__O__#",
+  "!!!!####__O__#",
+  "!!!!!!!##_O_##",
+  "!!!!!!!!#__##!",
+  "!!!!!!!!#__#!!",
   "!!!!!!!!####!!",
 }
 
