@@ -17,7 +17,7 @@ dofile(enigma.FindDataFile("levels/ralf_sokoban.lua"))
 
 level={
   "####!!!!!!",
-  "#_@###!!!!",
+  "#_a###!!!!",
   "#.*  #####",
   "#..#oo o #",
   "##       #",
