@@ -21,10 +21,10 @@ level={
   "!#   ##",
   "!#o*o #",
   "##._. #",
-  "#_.@.##",
-  "#_o*o#!",
-  "##___#!",
-  "!#___#!",
+  "# .a.##",
+  "# o*o#!",
+  "##   #!",
+  "!#   #!",
   "!#####!",
 }
 
