@@ -22,5 +22,5 @@ set_stone("st-grate1", 12, 8)
 oxyd(19, 4)
 oxyd(19, 8)
 
-set_actor("ac-blackball", 6.5, 6.5, {player=0})
+set_actor("ac-blackball", 6.5, 6.5)
 
