@@ -1,4 +1,8 @@
--- created by Martin Hawlisch
+--
+-- A level for Enigma
+--
+-- Copyright (c) 2003 Martin Hawlisch
+-- Licensed under the GPL version 2.
 
 levelw = 39
 levelh = 25
@@ -33,14 +37,13 @@ oxyd( 19,levelh-5)
 
 oxyd_shuffle()
 
-draw_stones("st-oneway", {levelw-8,16}, {1,0}, 4, {orientation=NORTH})
-draw_stones("st-oneway", {levelw-8, 8}, {1,0}, 4, {orientation=NORTH})
-draw_stones("st-oneway", {4,8}, {1,0}, 4, {orientation=SOUTH})
-draw_stones("st-oneway", {4,16}, {1,0}, 4, {orientation=SOUTH})
-draw_stones("st-oneway", {15,2}, {0,1}, 2, {orientation=WEST})
-draw_stones("st-oneway", {23,2}, {0,1}, 2, {orientation=WEST})
-draw_stones("st-oneway", {15,levelh-4}, {0,1}, 2, {orientation=EAST})
-draw_stones("st-oneway", {23,levelh-4}, {0,1}, 2, {orientation=EAST})
-
-set_actor("ac-blackball", 33, 21, {player=0})
+draw_stones("st-oneway-n", {levelw-8,16}, {1,0}, 4)
+draw_stones("st-oneway-n", {levelw-8, 8}, {1,0}, 4)
+draw_stones("st-oneway-s", {4,8}, {1,0}, 4)
+draw_stones("st-oneway-s", {4,16}, {1,0}, 4)
+draw_stones("st-oneway-w", {15,2}, {0,1}, 2)
+draw_stones("st-oneway-w", {23,2}, {0,1}, 2)
+draw_stones("st-oneway-e", {15,levelh-4}, {0,1}, 2)
+draw_stones("st-oneway-e", {23,levelh-4}, {0,1}, 2)
 
+set_actor("ac-blackball", 33, 21)
