@@ -1,4 +1,8 @@
--- created by Martin Hawlisch
+--
+-- A level for Enigma
+--
+-- Copyright (c) 2003 Martin Hawlisch
+-- Licensed under the GPL version 2.
 
 create_world( 20, 13)
 
@@ -30,5 +34,4 @@ set_item( "it-hammer", 9, 6)
 set_item( "it-umbrella", 9, 7)
 set_item( "it-dynamite", 10, 7)
 
-set_actor("ac-blackball", 10, 6.5, {player=0})
-
+set_actor("ac-blackball", 10, 6.5)
