@@ -1,4 +1,9 @@
--- created by Martin Hawlisch
+--
+-- A level for Enigma
+--
+-- Copyright (c) 2003 Martin Hawlisch
+-- Licensed under the GPL version 2.
+
 
 create_world( 57, 36)
 oxyd_default_flavor = "c"
@@ -37,7 +42,6 @@ oxyd_shuffle()
 set_item( "it-spring2", 25, 17)
 set_item( "it-spring1", 24, 25)
 
-set_actor("ac-blackball", 26, 17, {player=0, mouseforce=1})
-
-display.SetFollowMode(display.FOLLOW_SCROLLING)
+set_actor("ac-blackball", 26, 17)
 
+display.SetFollowMode(display.FOLLOW_SCREENSCROLLING)
