@@ -1,4 +1,9 @@
--- created by Martin Hawlisch
+--
+-- A level for Enigma
+--
+-- Copyright (c) 2003 Martin Hawlisch
+-- Licensed under the GPL version 2.
+
 
 create_world( 39, 13)
 oxyd_default_flavor = "c"
@@ -34,5 +39,4 @@ oxyd(17, 8)
 
 oxyd_shuffle()
 
-set_actor("ac-blackball", 6.5, 3.5, {player=0})
-
+set_actor("ac-blackball", 6.5, 3.5)
