@@ -10,9 +10,9 @@ Require("levels/ant.lua")
 cells={}
 cells[" "]=cell{floor="fl-inverse"}
 cells["#"]=cell{stone="st-rock1"}
-cells["."]=cell{item= {"it-crack", {type=1, fixed=1}}}
-cells[","]=cell{item= {"it-crack", {type=2, fixed=1}}}
-cells[":"]=cell{item= {"it-crack", {type=3, fixed=1}}}
+cells["."]=cell{item= {"it-crack1", {fixed=1}}}
+cells[","]=cell{item= {"it-crack2", {fixed=1}}}
+cells[":"]=cell{item= {"it-crack3", {fixed=1}}}
 
 level = {
    "####################",
