@@ -11,10 +11,10 @@ cells={}
 use_cells(cells, "W")
 cells[" "]=cell{floor="fl-rough"}
 cells["#"]=cell{stone="st-rock6"}
-cells["v"]=cell{item ={"it-puller", {orientation=SOUTH}}}
-cells["^"]=cell{item ={"it-puller", {orientation=NORTH}}}
-cells["<"]=cell{item ={"it-puller", {orientation=WEST}}}
-cells[">"]=cell{item ={"it-puller", {orientation=EAST}}}
+cells["v"]=cell{item ="it-puller-s"}
+cells["^"]=cell{item ="it-puller-n"}
+cells["<"]=cell{item ="it-puller-w"}
+cells[">"]=cell{item ="it-puller-e"}
 cells["Y"]=cell{{cells["W"],cells["^"]}}
 cells["Z"]=cell{{cells["W"],cells[">"]}}
 
