@@ -4,7 +4,8 @@
 -- Contact: 	amgine@reallysoft.de
 -- License: 	GPL v2.0 or above
 
-dofile(enigma.FindDataFile("levels/ant.lua")) -- Thanks to ant
+if dofile(enigma.FindDataFile("levels/ant.lua")) == nil then error("can't load 'ant.lua'"); end
+-- Thanks to ant
 
 -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- --
 -- draw maps of maps (metamaps)
@@ -112,9 +113,9 @@ end
 -- worldw/worldh        same including border
 -- xlo/ylo              left/upper corner coordinates (of map!)
 
-function rs_create_world(map,mapcells,floorcell,abysscell,bordercell)
-   floorcell = floorcell or cells[" "] or cell{floor={face="fl-normal"}}
-   abysscell = abysscell or cell{floor={face="fl-abyss"}}
+preferred_width,preferred_height = 20,13
+
+function rs_init_world(map, bordercell)
    mapw,maph = get_map_size(map)
 
    if (bordercell) then
@@ -124,17 +125,24 @@ function rs_create_world(map,mapcells,floorcell,abysscell,bordercell)
    end
 
    local rworldw,rworldh = worldw,worldh
-   if rworldw<20 then rworldw=20 end
-   if rworldh<13 then rworldh=13 end
+   if rworldw<preferred_width  then rworldw=preferred_width  end
+   if rworldh<preferred_height then rworldh=preferred_height end
 
    xlo = floor((rworldw-mapw-1)/2)+1
    ylo = floor((rworldh-maph-1)/2)+1
 
---   print("xlo="..xlo.." ylo="..ylo)
+   --print("xlo="..xlo.." ylo="..ylo)
 
    local oxyd_flavor = oxyd_default_flavor
    create_world(rworldw, rworldh)
    oxyd_default_flavor = oxyd_flavor
+end
+
+function rs_create_world(map,mapcells,floorcell,abysscell,bordercell)
+   floorcell = floorcell or cells[" "] or cell{floor={face="fl-normal"}}
+   abysscell = abysscell or cell{floor={face="fl-abyss"}}
+
+   rs_init_world(map,bordercell)
 
    fill_world_func(abysscell)
    fill_world_func(floorcell,xlo,ylo,mapw,maph)
