@@ -2,7 +2,7 @@
 #
 # This file creates a w32 binary release
 #
-VERSION=0.91
+VERSION=0.92
 DDIR="`pwd`/Enigma-$VERSION"
 SDIR=../..
 BDIR=../
@@ -52,7 +52,7 @@ function copy_data
     
     echo "... copying locales:"
     mkdir $DDIR/data/locale
-    for lang in de fr nl it; do
+    for lang in de fr nl it es; do
     	echo "$lang.gmo"
 	mkdir "$DDIR/data/locale/$lang"
 	mkdir "$DDIR/data/locale/$lang/LC_MESSAGES"
@@ -76,6 +76,7 @@ function copy_doc
     cptext doc/sounds.txt	doc/sounds.txt
     cptext doc/objects.txt	doc/objects.txt
     cptext doc/README.mingw32   doc/README-mingw32.txt
+    cptext doc/sound.lua        doc/sound.lua
     cpbuiltfile doc/refman/enigma-ref.html doc/
     cpfile doc/functions.html	doc/
     cpfile doc/functions.css	doc/
