@@ -251,7 +251,7 @@ void Client::handle_events()
             break;
         case SDL_ACTIVEEVENT: {
             update_mouse_button_state();
-            if (e.active.gain == 0) 
+            if (e.active.gain == 0 && !video::IsFullScreen())
                 show_menu();
             break;
         }
