@@ -1419,6 +1419,9 @@ bool DL_Shadows::has_actor (int x, int y)
     return m_hasactor(x, y);
 }
 
+/** Prepare the shadows layer for a redraw.  This routine
+    pre-calculates the tiles that currently are partially covered by
+    an actor.  */
 void DL_Shadows::prepare_draw (const WorldArea &wa) 
 {
     for (int i=0; i<wa.w; ++i) 
@@ -1427,7 +1430,7 @@ void DL_Shadows::prepare_draw (const WorldArea &wa)
 
     for (unsigned k=0; k<m_sprites->sprites.size(); ++k) {
         Sprite *s = m_sprites->sprites[k];
-        if (s && s->layer == SPRITE_ACTOR) {
+        if (s && s->layer == SPRITE_ACTOR && s->model) {
             Rect r, redrawr;
             s->model->get_extension (r);
             r.x += s->screenpos[0];
