@@ -1690,7 +1690,7 @@ namespace
         Vortex(bool opened);
 
     private:
-        static const double RANGE = 0.5/2;
+        static const double RANGE;
 
         // Item interface
         bool actor_hit(Actor*);
@@ -1745,6 +1745,8 @@ namespace
         {"it-vortex-closed", it_vortex_closed, itf_none, 0.0},
         {"it-vortex-open", it_vortex_open,     itf_none, 0.0}
     };
+
+    const double Vortex::RANGE = 0.5/2;
 }
 
 Vortex::Vortex(bool opened)
