@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002,2003 Daniel Heck
+ * Copyright (C) 2002,2003,2004 Daniel Heck
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -15,28 +15,28 @@
  * with this program; if not, write to the Free Software Foundation, Inc.,
  * 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: laser.cc,v 1.19.2.1 2003/09/23 22:46:20 dheck Exp $
+ * $Id: laser.cc,v 1.26 2004/03/15 20:15:35 dheck Exp $
  */
 #include "laser.hh"
 #include "sound.hh"
-#include "game.hh"
-#include "actors.hh"
+#include "stones_internal.hh"
+#include "server.hh"
 #include <algorithm>
 #include <cassert>
 #include <map>
 
-using namespace world::laser;
-using namespace world;
 using namespace std;
+using namespace world;
+using namespace lasers;
+
+using stones::maybe_push_stone;
+using px::V2;
 
-//======================================================================
-// TYPES
-//======================================================================
 namespace
 {
-//----------------------------------------
-// LaserBeam
-//----------------------------------------
+
+/* -------------------- LaserBeam -------------------- */
+
     class LaserBeam : public Item, public LaserEmitter {
     public:
         static void emit_from(GridPos p, Direction d);
@@ -45,18 +45,23 @@ namespace
 
 	// LaserEmitter interface
         DirectionBits emission_directions() const { return directions; }
+        static ItemTraits traits;
+
+        const ItemTraits &get_traits() const {
+            return traits;
+        }
     private:
-        LaserBeam(Direction dir) : Item("it-laserbeam") {
+        LaserBeam(Direction dir) {
             directions = to_bits(dir);
         }
 
         // Item interface.
-        bool on_laserhit(Direction dir);
-        void on_creation();
+        void on_laserhit(Direction dir);
+        void on_creation (GridPos p);
         void init_model();
         bool actor_hit(Actor *actor);
 
-        Object *clone() {
+        Item *clone() {
             // new LaserBeams may only created inside `emit_from'.
             assert(0);
             return 0;
@@ -69,10 +74,10 @@ namespace
         static vector<LaserBeam*> instances;
         static map<GridPos, int>  old_laser_positions;
     };
+    ItemTraits LaserBeam::traits = {"it-laserbeam", it_laserbeam, itf_indestructible, 0.0 };
 
-//----------------------------------------
-// Laser stones
-//----------------------------------------
+
+/* -------------------- Laser Stones -------------------- */
 
 /** \page st-laser Laser Stone
 
@@ -96,7 +101,7 @@ an incoming beam).
 \ref st-pmirror, \ref st-3mirror
 
 */
-    class LaserStone : public LaserEmitter, public OnOffStone {
+    class LaserStone : public LaserEmitter, public stones::OnOffStone {
     public:
         LaserStone (Direction dir=EAST);
         static void reemit_all();
@@ -111,7 +116,7 @@ an incoming beam).
 
         typedef std::vector<LaserStone*> InstanceList;
         static InstanceList instances;
-        Object *clone() {
+        Stone *clone() {
             LaserStone *o = new LaserStone(*this);
             instances.push_back(o);
             return o;
@@ -132,14 +137,13 @@ an incoming beam).
         Direction get_dir() const {return Direction(int_attrib("dir"));}
 
         // Stone interface.
-        void on_creation();
+        void on_creation (GridPos p);
         void init_model();
     };
 }
 
-//======================================================================
-// IMPLEMENTATIONS
-//======================================================================
+
+/* -------------------- PhotoCell -------------------- */
 
 vector<void*> PhotoCell::instances;
 
@@ -179,9 +183,9 @@ void PhotoCell::photo_deactivate()
         instances.erase(i);
 }
 
-//----------------------------------------
-// PhotoStone
-//----------------------------------------
+
+/* -------------------- PhotoStone -------------------- */
+
 void PhotoStone::check_state()
 {
     GridPos p = get_pos();
@@ -195,10 +199,9 @@ void PhotoStone::check_state()
     }
 }
 
+
+/* -------------------- LaserBeam -------------------- */
 
-//----------------------------------------
-// LaserBeam
-//
 // The implementation of laser beams is a little tricky because, in
 // spite of being implemented as Items, lasers aren't localized and
 // changes to any part of the beam can affect the beam elsewhere.  A
@@ -213,8 +216,8 @@ void PhotoStone::check_state()
 //
 // - LaserBeam::emit_from() is the only way to emit laser beams. A new
 //   beam will propagate automatically and stops only if it comes
-//   across a stone or or item that returns `false' from
-//   on_laserhit().
+//   across an item or a stone that returns `false' from
+//   Stone::is_transparent().
 //
 // - `on_laserhit()' is called for objects in the beam *whenever*
 //   the beam is recalculated.  For objects that need to be notified
@@ -223,7 +226,6 @@ void PhotoStone::check_state()
 //
 // More bits of information can be found in the description of laser
 // stones and mirrors.
-//----------------------------------------
 
 vector<LaserBeam*> LaserBeam::instances;
 map<GridPos, int>  LaserBeam::old_laser_positions;
@@ -240,7 +242,7 @@ void LaserBeam::init_model()
         set_model("it-laserv");
 }
 
-bool LaserBeam::on_laserhit(Direction dir)
+void LaserBeam::on_laserhit(Direction dir)
 {
     DirectionBits dirbit = to_bits(dir);
     if (!(directions & dirbit)) {
@@ -249,31 +251,32 @@ bool LaserBeam::on_laserhit(Direction dir)
         emit_from(get_pos(), dir);
         init_model();
     }
-    return false;
 }
 
-void LaserBeam::on_creation()
+void LaserBeam::on_creation (GridPos p)
 {
-    if (directions & EASTBIT) emit_from(get_pos(), EAST);
-    if (directions & WESTBIT) emit_from(get_pos(), WEST);
-    if (directions &NORTHBIT) emit_from(get_pos(), NORTH);
-    if (directions &SOUTHBIT) emit_from(get_pos(), SOUTH);
+    if (directions & EASTBIT) emit_from(p, EAST);
+    if (directions & WESTBIT) emit_from(p, WEST);
+    if (directions &NORTHBIT) emit_from(p, NORTH);
+    if (directions &SOUTHBIT) emit_from(p, SOUTH);
     init_model();
 }
 
-void LaserBeam::emit_from(GridPos p, Direction d)
+void LaserBeam::emit_from(GridPos p, Direction dir)
 {
     bool may_pass = true;
 
-    p.move(d);
-    if (Stone *st = GetStone(p))
-        may_pass = st->on_laserhit(d);
+    p.move(dir);
+    if (Stone *st = GetStone(p)) {
+        may_pass = st->is_transparent (dir);
+        st->on_laserhit (dir);
+    }
 
     if (may_pass) {
         if (Item *it = GetItem(p))
-            it->on_laserhit(d);
+            it->on_laserhit (dir);
         else {
-            LaserBeam *lb = new LaserBeam(d);
+            LaserBeam *lb = new LaserBeam (dir);
             SetItem(p, lb);
             instances.push_back(lb);
         }
@@ -282,7 +285,7 @@ void LaserBeam::emit_from(GridPos p, Direction d)
 
 bool LaserBeam::actor_hit(Actor *actor)
 {
-    double r = actor->get_radius();
+    double r = get_radius(actor);
     V2 p = actor->get_pos();
     GridPos gp = get_pos();
 
@@ -346,7 +349,7 @@ void LaserBeam::all_emitted()
     }
 
     if (count) {
-        sound::PlaySound("st-laser", px::V2(x/count+.5, y/count+.5));
+        sound::SoundEvent ("laseron", px::V2(x/count+.5, y/count+.5));
     }
 
     old_laser_positions.clear();
@@ -400,11 +403,11 @@ void LaserStone::emit_light()
         LaserBeam::emit_from(get_pos(), get_dir());
 }
 
-void LaserStone::on_creation()
+void LaserStone::on_creation (GridPos p)
 {
     if (is_on())
         RecalcLight();
-    Stone::on_creation();
+    Stone::on_creation(p);
 }
 
 void LaserStone::init_model()
@@ -414,9 +417,8 @@ void LaserStone::init_model()
     set_model(mname);
 }
 
-//----------------------------------------
-// MirrorStone
-//----------------------------------------
+
+/* -------------------- MirrorStone -------------------- */
 namespace
 {
     class MirrorStone
@@ -426,7 +428,7 @@ namespace
         MirrorStone(const char *name, bool movable=false, bool transparent=false);
 
         bool is_transparent() const { return int_attrib("transparent"); }
-        bool is_movable() { return int_attrib("movable"); }
+        bool is_movable() const { return int_attrib("movable"); }
 
         void set_orientation(int o) { set_attrib("orientation", o); }
         int get_orientation() { return int_attrib("orientation"); }
@@ -454,9 +456,10 @@ namespace
         void on_recalc_finish() {}
 
         // Stone interface
-        void actor_hit(const StoneContact &sc);
-        void on_creation();
-        void on_removal();
+        void actor_hit(const world::StoneContact &sc);
+        void on_creation (GridPos p);
+        void on_removal (GridPos p);
+        bool is_transparent(Direction) const { return is_transparent(); }
 
         // Private methods
         void rotate_right();
@@ -467,17 +470,14 @@ namespace
 }
 
 MirrorStone::MirrorStone(const char *name, bool movable, bool transparent)
-: Stone(name)
-, outdirs(NODIRBIT)
+: Stone(name), outdirs(NODIRBIT)
 {
     set_attrib("transparent", transparent);
     set_attrib("movable", movable);
     set_attrib("orientation", Value(1));
 }
 
-void
-MirrorStone::init_model()
-{
+void MirrorStone::init_model() {
     string mname = get_kind();
     mname += is_movable() ? "-m" : "-s";
     mname += is_transparent() ? "t" : "o";
@@ -485,63 +485,54 @@ MirrorStone::init_model()
     set_model(mname);
 }
 
-void
-MirrorStone::message(const string &m, const Value &)
-{
+void MirrorStone::message(const string &m, const Value &val) {
     if (m == "trigger" || m=="turn") {
         rotate_right();
     }
-{
-    if (m == "mirror-north") {
-        set_attrib("orientation", Value(3));
-        set_orientation(get_orientation());
-        init_model();
-        MaybeRecalcLight(get_pos());
-    }
-{
-    if (m == "mirror-east") {
-        set_attrib("orientation", Value(4));
-        set_orientation(get_orientation());
-        init_model();
-        MaybeRecalcLight(get_pos());
-    }
-{
-    if (m == "mirror-south") {
-        set_attrib("orientation", Value(1));
-        set_orientation(get_orientation());
-        init_model();
-        MaybeRecalcLight(get_pos());
-    }
-{
-    if (m == "mirror-west") {
-        set_attrib("orientation", Value(2));
-        set_orientation(get_orientation());
-        init_model();
-        MaybeRecalcLight(get_pos());
-    }
+    else if (m == "signal") {
+        if (to_double(val) != 0) {
+            rotate_right();
         }
-      }
     }
-  }
+    else if (m == "mirror-north") {
+        set_orientation(3);
+        init_model();
+        MaybeRecalcLight(get_pos());
+    }
+    else if (m == "mirror-east") {
+        set_orientation(4);
+        init_model();
+        MaybeRecalcLight(get_pos());
+    }
+    else if (m == "mirror-south") {
+        set_orientation(1);
+        init_model();
+        MaybeRecalcLight(get_pos());
+    }
+    else if (m == "mirror-west") {
+        set_orientation(2);
+        init_model();
+        MaybeRecalcLight(get_pos());
+    }
 }
 
-void MirrorStone::actor_hit(const StoneContact &sc)
+void MirrorStone::actor_hit(const world::StoneContact &sc)
 {
     if (is_movable())
         maybe_push_stone(sc);
     rotate_right();
 }
 
-void MirrorStone::on_creation()
+void MirrorStone::on_creation (GridPos p)
 {
     photo_activate();
-    Stone::on_creation();
+    Stone::on_creation(p);
 }
 
-void MirrorStone::on_removal()
+void MirrorStone::on_removal(GridPos p)
 {
     photo_deactivate();
-    Stone::on_removal();
+    Stone::on_removal(p);
 }
 
 void MirrorStone::rotate_right()
@@ -549,17 +540,12 @@ void MirrorStone::rotate_right()
     set_orientation(1+(get_orientation() % 4));
     init_model();
     MaybeRecalcLight(get_pos());
-    play_sound("st-mirrorturn");
+    sound_event ("mirrorturn");
 }
 
 
-//----------------------------------------
-// PlaneMirror
-//----------------------------------------
-
-/** \page st-pmirror Plane Mirror Stone
-
-*/
+
+/* -------------------- Plane Mirror -------------------- */
 namespace
 {
     class PlaneMirror : public MirrorStone {
@@ -579,12 +565,11 @@ namespace
             const char *a = " -\\|/";
             return a[MirrorStone::get_orientation()];
         }
-        bool on_laserhit(Direction dir);
+        void on_laserhit(Direction dir);
     };
 }
 
-bool
-PlaneMirror::on_laserhit(Direction dir)
+void PlaneMirror::on_laserhit(Direction dir) 
 {
     char orientation = GetOrientation();
     bool transparent = is_transparent();
@@ -597,7 +582,7 @@ PlaneMirror::on_laserhit(Direction dir)
                 emit_light(dir);
         }
         else if ((dir == NORTH || dir == SOUTH) && transparent &&
-                 enigma::GameCompatibility == GAMET_OXYD1) {
+                 server::GameCompatibility == GAMET_OXYD1) {
             emit_light(dir);
         }
         break;
@@ -608,7 +593,7 @@ PlaneMirror::on_laserhit(Direction dir)
                 emit_light(dir);
         }
         else if ((dir == EAST || dir == WEST) && transparent &&
-                 enigma::GameCompatibility == GAMET_OXYD1) {
+                 server::GameCompatibility == GAMET_OXYD1) {
             emit_light(dir);
         }
         break;
@@ -635,17 +620,10 @@ PlaneMirror::on_laserhit(Direction dir)
             emit_light(dir);
         break;
     }
-    return false;
 }
 
-//----------------------------------------
-// TriangleMirror
-//----------------------------------------
-
-/** \page st-3mirror Triangle Mirror Stone
-
-
-*/
+
+/* -------------------- TriangleMirror -------------------- */
 
 namespace
 {
@@ -664,11 +642,9 @@ namespace
         CLONEOBJ(TriangleMirror);
     public:
         TriangleMirror(char orientation='v', bool movable=false, bool transparent=false)
-            : MirrorStone("st-3mirror", movable, transparent)
+        : MirrorStone("st-3mirror", movable, transparent)
         {
-//             const int a[] = { 4, 3, 2, 1 }; // direction -> orientation (weird)
-//             set_orientation(a[dir]);
-            SetOrientation(orientation);
+            SetOrientation (orientation);
         }
     private:
 
@@ -682,12 +658,11 @@ namespace
             const Direction a[] = {NODIR, NORTH, EAST, SOUTH, WEST};
             return a[MirrorStone::get_orientation()];
         }
-        bool on_laserhit(Direction dir);
+        void on_laserhit (Direction dir);
     };
 }
 
-bool
-TriangleMirror::on_laserhit(Direction beam_dir)
+void TriangleMirror::on_laserhit(Direction beam_dir)
     // note: 'beam_dir' is the direction where laserbeam goes to
 {
     // direction where flat side of triangle points to
@@ -711,8 +686,6 @@ TriangleMirror::on_laserhit(Direction beam_dir)
 
     if (is_transparent())
         emit_light(beam_dir);
-
-    return false;
 }
 
 //----------------------------------------------------------------------
@@ -725,9 +698,7 @@ namespace
     bool light_recalc_scheduled = false;
 }
 
-void
-world::laser::Init()
-{
+void lasers::Init() {
     Register (new LaserStone);
     Register ("st-laser-n", new LaserStone(NORTH));
     Register ("st-laser-e", new LaserStone(EAST));
@@ -772,23 +743,17 @@ world::laser::Init()
 }
 
 
-void
-world::laser::MaybeRecalcLight(GridPos p)
-{
+void lasers::MaybeRecalcLight(GridPos p) {
     light_recalc_scheduled |=
         (LightFrom(p, NORTH) || LightFrom(p, SOUTH) ||
          LightFrom(p, WEST) || LightFrom(p, EAST));
 }
 
-void
-world::laser::RecalcLight()
-{
+void lasers::RecalcLight() {
     light_recalc_scheduled = true;
 }
 
-bool
-world::laser::LightFrom(GridPos p, Direction dir)
-{
+bool lasers::LightFrom (GridPos p, Direction dir) {
     p.move(dir);
     if (LaserEmitter *le = dynamic_cast<LaserEmitter*>(GetStone(p)))
         if (has_dir(le->emission_directions(), reverse(dir)))
@@ -798,9 +763,7 @@ world::laser::LightFrom(GridPos p, Direction dir)
     return false;
 }
 
-void
-world::laser::RecalcLightNow()
-{
+void lasers::RecalcLightNow() {
     if (light_recalc_scheduled) {
         PhotoCell::notify_start();
         LaserBeam::kill_all();
