@@ -1001,7 +1001,8 @@ Language languages[] = {
     { "default",                "" },
     { "Deutsch",                "de_DE" },
     { "English",                "en_EN" },
-    { "Fran\303\247ais",        "fr_FR" },
+    { "Español",         "es_ES" },
+    { "Français",        "fr_FR" },
     { "Italiano",               "it_IT" },
     { "Nederlands",             "nl_NL" },
 };
