@@ -2105,6 +2105,26 @@ namespace
         enum State { CLOSED, OPEN, OPENING, CLOSING, BLINKING };
         State state;
 
+        // Stone interface
+        void actor_hit(const StoneContact &sc);
+        void on_creation (GridPos p);
+        void on_removal (GridPos p);
+        const char *collision_sound() { return "stone"; }
+        void message(const string &m, const Value &);
+
+
+        // PhotoStone interface
+        void notify_laseron() { maybe_open_stone(); }
+        void notify_laseroff() {}
+
+        // Animation callback
+        void animcb();
+
+        // Private methods
+        void maybe_open_stone();
+        void change_state(State newstate);
+
+
         static bool blinking(OxydStone *a) {
             return (a->state==BLINKING);
         }
@@ -2115,21 +2135,6 @@ namespace
             return !(a->state==OPEN || a->state==OPENING);
         }
 
-        // Stone interface
-        void actor_hit(const StoneContact &sc);
-        void on_creation (GridPos p);
-        void on_removal (GridPos p);
-        const char *collision_sound() { return "stone"; }
-        void message(const string &m, const Value &);
-
-        // Animation callback
-        void animcb();
-
-        void maybe_open_stone();
-        void change_state(State newstate);
-
-        void notify_laseron() { maybe_open_stone(); }
-        void notify_laseroff() {}
     };
 }
 
@@ -2165,9 +2170,7 @@ void OxydStone::message(const string &m, const Value &val) {
 }
 
 void OxydStone::shuffle_colors() {
-    string      icolor, acolor;
     vector<int> closed_oxyds;
-
     unsigned isize = instances.size();
     for (unsigned i=0; i<isize; ++i) {
         if (instances[i]->state == CLOSED) {
@@ -2184,17 +2187,12 @@ void OxydStone::shuffle_colors() {
             OxydStone *o1 = instances[closed_oxyds[i]];
             OxydStone *o2 = instances[closed_oxyds[a]];
 
-            assert(o1 && o2);
-            assert(o1->state == CLOSED);
-            assert(o2->state == CLOSED);
-
+            string icolor, acolor;
             o1->string_attrib("color", &icolor);
             o2->string_attrib("color", &acolor);
 
-            if (icolor != acolor) {
-                o1->set_attrib("color", acolor.c_str());
-                o2->set_attrib("color", icolor.c_str());
-            }
+            o1->set_attrib("color", acolor.c_str());
+            o2->set_attrib("color", icolor.c_str());
         }
     }
 }
