@@ -301,7 +301,7 @@ void MouseCursor::restore_bg () {
 }
 
 
-/* -------------------- Variables -------------------- */
+/* -------------------- Local Variables -------------------- */
 namespace
 {
     Video_SDL   *video_engine = 0;
@@ -493,6 +493,7 @@ void video::Init()
     assert (NUMENTRIES(video_modes) == VM_COUNT);
 
     int vidmode = Clamp (options::GetInt("VideoMode"), 0, VM_COUNT-1);
+    int oldvidmode = vidmode;
 
     video_engine = new Video_SDL();
 
@@ -523,6 +524,10 @@ void video::Init()
     }
 
     current_video_mode = static_cast<VideoModes>(vidmode);
+    if (vidmode != oldvidmode) {
+        options::SetOption ("VideoMode", vidmode);
+    }
+
 
 #ifndef MACOSX
     Surface *icn = enigma::GetImage("enigma_marble");
@@ -622,7 +627,6 @@ void video::Screenshot (const std::string &fname)
     enigma::Log << "Wrote screenshot to '" << fname << "\n";
 }
 
-
 
 /* -------------------- Special Effects -------------------- */
 
