@@ -925,7 +925,11 @@ void World::handle_actor_contact (unsigned i, unsigned j)
 void World::handle_contacts (unsigned actoridx) 
 {
     Actor *actor1 = actorlist[actoridx];
-//     ActorInfo &a1 = *actor1->get_actorinfo();
+    ActorInfo &a1 = *actor1->get_actorinfo();
+
+
+    if (a1.ignore_contacts)     // used by the cannonball for example
+        return;
 
     // Handle contacts with stones
     StoneContactList cl;
@@ -1407,29 +1411,20 @@ void world::PerformAction (Object *o, bool onoff)
 }
 
 
-
-// explosion messages:
-// -------------------
-//
-// "ignite"    : (sent by dynamite)
-// "expl"      : (sent by bomb)
-// "bombstone" : (sent by bombstone)
-
 namespace
 {
-    void explosion (GridPos p, ItemID expl)
+    void explosion (GridPos p, ItemID explosion_item)
     {
-        Item  *item  = GetItem(p);
         Stone *stone = GetStone(p);
         SendMessage(stone, "expl");
-        if (item) {
+        if (Item  *item  = GetItem(p)) {
             if (has_flags(item, itf_indestructible))
                 SendMessage(item, "expl");
             else
-                SetItem(p, expl);
+                SetItem(p, explosion_item);
         }
         else
-            SetItem(p, MakeItem (expl));
+            SetItem(p, explosion_item);
     }
 }
 
